from setuptools import setup

setup(name='plk345_distributions',
      version='2.6',
      description='Gaussian distributions',
      packages=['plk345_distributions'],
      author = 'Irving Chow',
      author_email = '1624000827@qq.com',
      zip_safe=False)
